@@ -3,7 +3,7 @@ import csv
 import os
 import shutil
 from pathlib import Path
-from typing import Any, Dict, Mapping, Optional
+from typing import Any, Dict, Mapping, Union
 
 from kiara import KiaraModule, Value, ValueMap, ValueMapSchema
 from kiara.exceptions import KiaraProcessingException
@@ -93,8 +93,6 @@ class CreateGraphFromTablesModule(KiaraModule):
 
     def process(self, inputs: ValueMap, outputs: ValueMap) -> None:
 
-        pass
-
         edges = inputs.get_value_obj("edges")
         edges_table: KiaraTable = edges.data
         edges_source_column_name = inputs.get_value_data("source_column_name")
@@ -139,7 +137,7 @@ class CreateGraphFromTablesModule(KiaraModule):
             column_map=edges_column_map,
         )
 
-        nodes_table: Optional[KiaraTable] = None
+        nodes_table: Union[KiaraTable, None] = None
         if nodes.is_set:
             if (
                 id_column_name in nodes_column_map.keys()
@@ -153,6 +151,8 @@ class CreateGraphFromTablesModule(KiaraModule):
 
             nodes_table = nodes.data
 
+            assert nodes_table is not None
+
             extra_schema = []
             if label_column_name is None:
                 label_column_name = LABEL_COLUMN_NAME
@@ -193,9 +193,9 @@ class CreateGraphFromTablesModule(KiaraModule):
         else:
             nodes_data_schema = None
 
-        network_data = NetworkData.create_in_temp_dir(
-            edges_schema=edges_data_schema,
-            nodes_schema=nodes_data_schema,
+        network_data = NetworkData.create_network_data_in_temp_dir(
+            schema_edges=edges_data_schema,
+            schema_nodes=nodes_data_schema,
             keep_unlocked=True,
         )
 
